@@ -1,9 +1,27 @@
 .onLoad <- function(libname = find.package("grattan"), pkgname = "grattan") {
   
   op <- options()
+  the_tempdir <- tempdir()
+  
   opgrattan <- list(
     "grattan.verbose" = FALSE,
-    "grattan.assume1901_2100" = TRUE
+    "grattan.assume1901_2100" = TRUE,
+    "grattan.taxstats.lib" = {
+      if (any(grepl("taxstatslib", list.dirs(path = the_tempdir, 
+                                             recursive = FALSE, 
+                                             full.names = FALSE)))) {
+        lib <- file.path(the_tempdir, 
+                         grep("taxstatslib", 
+                              list.dirs(path = the_tempdir,
+                                        recursive = FALSE,
+                                        full.names = FALSE),
+                              value = TRUE,
+                              fixed = TRUE)[1])
+      } else {
+        lib <- tempfile("taxstatslib", tmpdir = the_tempdir)
+      }
+      lib
+    }
   )
   toset <- !(names(opgrattan) %in% names(op))
   if (any(toset)) options(opgrattan[toset])
@@ -74,11 +92,14 @@
   
   tryCatch({
     f_mtimes <- 
-      if (file.exists("R/zzz.R")) {
-        c(vapply(dir(path = "R", full.names = TRUE), file.mtime, double(1)),
-          vapply(dir(path = "tests/testthat", full.names = TRUE), file.mtime, double(1)))
-      } else if (file.exists(file.path(find.package("grattan"), "NAMESPACE"))) {
-        sapply(file.path(find.package("grattan"), "NAMESPACE"), file.mtime)
+      # Display last file changed when on local machine only
+      if (identical(Sys.info()[["user"]], "hughp")) {
+        if (file.exists("R/grattan-package.R")) {
+          c(vapply(dir(path = "R", full.names = TRUE), file.mtime, double(1)),
+            vapply(dir(path = "tests/testthat", full.names = TRUE), file.mtime, double(1)))
+        } else if (file.exists(file.path(find.package("grattan"), "NAMESPACE"))) {
+          sapply(file.path(find.package("grattan"), "NAMESPACE"), file.mtime)
+        }
       }
     if (length(f_mtimes)) {
       class(f_mtimes) <- "POSIXct"
@@ -99,6 +120,7 @@
 
 gessage <- function(...) {
   if (identical(Sys.info()[["user"]], "hughp") &&
+      identical(.Platform$GUI, "RStudio") &&
       !isNamespaceLoaded("pkgdown") &&
       file.exists("~/grattan_1.4.0.2.tar.gz")) {
     packageStartupMessage(...)
